Web View
========

The Web View widget is used for displaying an embedded browser window within an application

Usage
-----

.. code-block:: Python

    import toga

    web = toga.WebView(url='https://google.com')

Supported Platforms
-------------------

.. include:: ../supported_platforms/WebView.rst

Reference
---------

.. autoclass:: toga.interface.widgets.webview.WebView
   :members:
   :undoc-members:
   :inherited-members: